@@ -12,12 +12,12 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="75"/>
+        <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>LXQt Power Manager Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="75"/>
+        <location filename="../lxqtpowermanager.cpp" line="76"/>
         <source>Hibernate failed.</source>
         <translation></translation>
     </message>
@@ -25,7 +25,7 @@
 <context>
     <name>LXQt::NotificationPrivate</name>
     <message>
-        <location filename="../lxqtnotification.cpp" line="154"/>
+        <location filename="../lxqtnotification.cpp" line="161"/>
         <source>Notifications Fallback</source>
         <translation></translation>
     </message>
@@ -33,93 +33,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="118"/>
+        <location filename="../lxqtpowermanager.cpp" line="108"/>
         <source>Hibernate</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="125"/>
+        <location filename="../lxqtpowermanager.cpp" line="115"/>
         <source>Suspend</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="132"/>
+        <location filename="../lxqtpowermanager.cpp" line="122"/>
         <source>Reboot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="139"/>
+        <location filename="../lxqtpowermanager.cpp" line="129"/>
         <source>Shutdown</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="146"/>
+        <location filename="../lxqtpowermanager.cpp" line="136"/>
         <source>Logout</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="158"/>
+        <location filename="../lxqtpowermanager.cpp" line="148"/>
         <source>LXQt Session Suspend</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="159"/>
+        <location filename="../lxqtpowermanager.cpp" line="149"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="168"/>
+        <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Hibernate</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="169"/>
+        <location filename="../lxqtpowermanager.cpp" line="159"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="178"/>
+        <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>LXQt Session Reboot</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="188"/>
+        <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>LXQt Session Shutdown</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="189"/>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="198"/>
+        <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>LXQt Session Logout</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="199"/>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="207"/>
-        <location filename="../lxqtpowermanager.cpp" line="212"/>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>LXQt Power Manager Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
         <source>Hibernate failed.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="212"/>
+        <location filename="../lxqtpowermanager.cpp" line="202"/>
         <source>Suspend failed.</source>
         <translation></translation>
     </message>
@@ -129,12 +129,12 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="161"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="165"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="243"/>
@@ -150,7 +150,7 @@
 <context>
     <name>QCoreApplication</name>
     <message>
-        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
+        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="47"/>
         <source>Choose the page to be shown.</source>
         <translation></translation>
     </message>
