@@ -129,12 +129,12 @@
     <message>
         <location filename="../lxqtscreensaver.cpp" line="161"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Error al ejecutar &quot;%1&quot;. Asegúrese de tener un salvapantallas compatible con xdg-screensaver instalado y funcionando.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="165"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Error al ejecutar &quot;%1&quot;.  Asegúrese de que el casillero/protector de pantalla especificado esté instalado y funcionando.</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="243"/>
